@@ -581,6 +581,19 @@ libvirt_virStreamPtrWrap(virStreamPtr node)
     return ret;
 }
 
+PyObject *
+libvirt_virDomainCheckpointPtrWrap(virDomainCheckpointPtr node)
+{
+    PyObject *ret;
+
+    if (node == NULL) {
+        return VIR_PY_NONE;
+    }
+
+    ret = libvirt_buildPyObject(node, "virDomainCheckpointPtr", NULL);
+    return ret;
+}
+
 PyObject *
 libvirt_virDomainSnapshotPtrWrap(virDomainSnapshotPtr node)
 {
